@@ -9,7 +9,6 @@ def api_v4(self):
     user_load_balancers(self)
     user_load_balancing_analytics(self)
     user_tokens_verify(self)
-    user_workers(self)
 
     # The API commands for /zones/
     zones(self)
@@ -32,6 +31,8 @@ def api_v4(self):
     zones_ssl(self)
     zones_waiting_rooms(self)
     zones_workers(self)
+    zones_extras(self)
+    zones_email(self)
 
     # The API commands for /railguns/
     railguns(self)
@@ -52,6 +53,8 @@ def api_v4(self):
     accounts_load_balancers(self)
     accounts_secondary_dns(self)
     accounts_stream(self)
+    accounts_extras(self)
+    accounts_email(self)
 
     # The API commands for /memberships/
     memberships(self)
@@ -67,8 +70,8 @@ def user(self):
     self.add('AUTH', "user/billing/history")
     self.add('AUTH', "user/billing/profile")
     self.add('VOID', "user/billing/subscriptions")
-    self.add('AUTH', "user/billing/subscriptions/apps")
-    self.add('AUTH', "user/billing/subscriptions/zones")
+#   self.add('AUTH', "user/billing/subscriptions/apps")
+#   self.add('AUTH', "user/billing/subscriptions/zones")
     self.add('VOID', "user/firewall")
     self.add('VOID', "user/firewall/access_rules")
     self.add('AUTH', "user/firewall/access_rules/rules")
@@ -83,14 +86,18 @@ def zones(self):
     self.add('AUTH', "zones", "activation_check")
     self.add('AUTH', "zones", "available_plans")
     self.add('AUTH', "zones", "available_rate_plans")
+    self.add('AUTH', "zones", "bot_management")
     self.add('AUTH', "zones", "custom_certificates")
     self.add('AUTH', "zones", "custom_certificates/prioritize")
+    self.add("AUTH", "zones", "custom_csrs")
     self.add('AUTH', "zones", "custom_hostnames")
     self.add('AUTH', "zones", "custom_hostnames/fallback_origin")
+    self.add('AUTH', 'zones', 'custom_ns')
     self.add('AUTH', "zones", "custom_pages")
     self.add('AUTH', "zones", "dns_records")
     self.add('AUTH', "zones", "dns_records/export")
     self.add('AUTH', "zones", "dns_records/import")
+    self.add('AUTH', 'zones', 'dns_records/scan')
     self.add('AUTH', "zones", "filters")
     self.add('AUTH', "zones", "healthchecks")
     self.add('AUTH', "zones", "healthchecks/preview")
@@ -100,8 +107,6 @@ def zones(self):
     self.add('AUTH', "zones", "purge_cache")
     self.add('AUTH', "zones", "railguns")
     self.add('AUTH', "zones", "railguns", "diagnose")
-    self.add('AUTH', 'zones', 'rulesets')
-    self.add('AUTH', 'zones', 'rulesets', 'versions')
     self.add('VOID', "zones", "security")
     self.add('AUTH', "zones", "security/events")
     self.add('AUTH', "zones", "subscription")
@@ -154,13 +159,16 @@ def zones_settings(self):
     self.add('AUTH', "zones", "settings/waf")
     self.add('AUTH', "zones", "settings/webp")
     self.add('AUTH', "zones", "settings/websockets")
+    self.add('AUTH', 'zones', 'settings/early_hints')
+    self.add('AUTH', 'zones', 'settings/proxy_read_timeout')
+    self.add('AUTH', 'zones', 'settings/ssl_recommender')
 
 def zones_analytics(self):
     """ API core commands for Cloudflare API"""
 
     self.add('VOID', "zones", "analytics")
-    self.add('AUTH', "zones", "analytics/colos")
-    self.add('AUTH', "zones", "analytics/dashboard")
+#   self.add('AUTH', "zones", "analytics/colos")
+#   self.add('AUTH', "zones", "analytics/dashboard")
     self.add('AUTH', "zones", "analytics/latency")
     self.add('AUTH', "zones", "analytics/latency/colos")
 
@@ -271,6 +279,7 @@ def zones_ssl(self):
     self.add('AUTH', "zones", "ssl/certificate_packs")
     self.add('AUTH', 'zones', 'ssl/certificate_packs/order')
     self.add('AUTH', 'zones', 'ssl/certificate_packs/quota')
+    self.add('AUTH', 'zones', 'ssl/recommendation')
     self.add('AUTH', "zones", "ssl/verification")
     self.add('VOID', "zones", "ssl/universal")
     self.add('AUTH', "zones", "ssl/universal/settings")
@@ -302,6 +311,12 @@ def zones_secondary_dns(self):
 
     self.add('AUTH', "zones", "secondary_dns")
     self.add('AUTH', "zones", "secondary_dns/force_axfr")
+    self.add('AUTH', 'zones', 'secondary_dns/incoming')
+    self.add('AUTH', 'zones', 'secondary_dns/outgoing')
+    self.add('AUTH', 'zones', 'secondary_dns/outgoing/disable')
+    self.add('AUTH', 'zones', 'secondary_dns/outgoing/enable')
+    self.add('AUTH', 'zones', 'secondary_dns/outgoing/force_notify')
+    self.add('AUTH', 'zones', 'secondary_dns/outgoing/status')
 
 def user_load_balancers(self):
     """ API core commands for Cloudflare API"""
@@ -316,12 +331,6 @@ def user_load_balancers(self):
     self.add('AUTH', "user/load_balancers/pools", "preview")
     self.add('AUTH', 'user/load_balancers/pools', 'references')
 
-def user_workers(self):
-    """ API core commands for Cloudflare API"""
-
-    self.add('VOID', "user/workers")
-    self.add('AUTH', "user/workers/scripts")
-
 def user_audit_logs(self):
     """ API core commands for Cloudflare API"""
 
@@ -347,20 +356,37 @@ def accounts(self):
     self.add('AUTH', "accounts")
     self.add('VOID', "accounts", "billing")
     self.add('AUTH', "accounts", "billing/profile")
+
+    self.add('AUTH', 'accounts', 'cfd_tunnel')
+    self.add('AUTH', 'accounts', 'cfd_tunnel', 'connections')
+    self.add('AUTH', 'accounts', 'cfd_tunnel', 'token')
+
     self.add('AUTH', "accounts", "custom_pages")
+
     self.add('AUTH', "accounts", "members")
+
     self.add('AUTH', "accounts", "railguns")
     self.add('AUTH', "accounts", "railguns", "connections")
+
     self.add('VOID', "accounts", "registrar")
     self.add('AUTH', "accounts", "registrar/domains")
+    self.add('AUTH', "accounts", "registrar/contacts")
+
     self.add('AUTH', "accounts", "roles")
+
     self.add('VOID', 'accounts', 'rules')
     self.add('AUTH', 'accounts', 'rules/lists')
     self.add('AUTH', 'accounts', 'rules/lists', 'items')
     self.add('AUTH', 'accounts', 'rules/lists/bulk_operations')
+
     self.add('AUTH', 'accounts', 'rulesets')
     self.add('AUTH', 'accounts', 'rulesets', 'versions')
-    self.add('AUTH', 'accounts', 'rulesets/import')
+    self.add('AUTH', 'accounts', 'rulesets', 'rules')
+#   self.add('AUTH', 'accounts', 'rulesets/import')
+    self.add('VOID', 'accounts', 'rulesets/phases')
+    self.add('AUTH', 'accounts', 'rulesets/phases', 'entrypoint')
+    self.add('AUTH', 'accounts', 'rulesets/phases', 'entrypoint/versions')
+
     self.add('VOID', "accounts", "storage")
     self.add('AUTH', "accounts", "storage/analytics")
     self.add('AUTH', "accounts", "storage/analytics/stored")
@@ -369,21 +395,35 @@ def accounts(self):
     self.add('AUTH', "accounts", "storage/kv/namespaces", "bulk")
     self.add('AUTH', "accounts", "storage/kv/namespaces", "keys")
     self.add('AUTH', "accounts", "storage/kv/namespaces", "values")
+    self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'metadata')
+
     self.add('AUTH', "accounts", "subscriptions")
+
     self.add('AUTH', 'accounts', 'tunnels')
     self.add('AUTH', 'accounts', 'tunnels', 'connections')
+
     self.add('AUTH', "accounts", "virtual_dns")
     self.add('VOID', "accounts", "virtual_dns", "dns_analytics")
     self.add('AUTH', "accounts", "virtual_dns", "dns_analytics/report")
     self.add('AUTH', "accounts", "virtual_dns", "dns_analytics/report/bytime")
-    self.add('VOID', "accounts", "workers")
-    self.add('AUTH', "accounts", "workers/scripts")
+
+    self.add('VOID', 'accounts', 'workers')
+    self.add('AUTH', 'accounts', 'workers/account-settings')
+    self.add('VOID', 'accounts', 'workers/durable_objects')
+    self.add('AUTH', 'accounts', 'workers/durable_objects/namespaces')
+    self.add('AUTH', 'accounts', 'workers/durable_objects/namespaces', 'objects')
+    self.add('AUTH', 'accounts', 'workers/scripts')
     self.add('AUTH', 'accounts', 'workers/scripts', 'schedules')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'tails')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'usage-model')
+    self.add('AUTH', 'accounts', 'workers/subdomain')
 
 def accounts_addressing(self):
     """ API core commands for Cloudflare API"""
 
     self.add('VOID', "accounts", "addressing")
+    self.add('AUTH', 'accounts', 'addressing/loa_documents')
+    self.add('AUTH', 'accounts', 'addressing/loa_documents', 'download')
     self.add('AUTH', "accounts", "addressing/prefixes")
     self.add('VOID', "accounts", "addressing/prefixes", "bgp")
     self.add('AUTH', "accounts", "addressing/prefixes", "bgp/status")
@@ -420,22 +460,29 @@ def accounts_secondary_dns(self):
     """ API core commands for Cloudflare API"""
 
     self.add('VOID', "accounts", "secondary_dns")
-    self.add('AUTH', "accounts", "secondary_dns/masters")
-    self.add('AUTH', 'accounts', 'secondary_dns/primaries')
+#   self.add('AUTH', "accounts", "secondary_dns/masters")
+#   self.add('AUTH', 'accounts', 'secondary_dns/primaries')
     self.add('AUTH', "accounts", "secondary_dns/tsigs")
+    self.add('AUTH', 'accounts', 'secondary_dns/acls')
+    self.add('AUTH', 'accounts', 'secondary_dns/peers')
 
 def accounts_stream(self):
     """ API core commands for Cloudflare API"""
 
     self.add('AUTH', "accounts", "stream")
     self.add('AUTH', "accounts", "stream", "captions")
+    self.add('AUTH', "accounts", "stream", "embed")
+    self.add('AUTH', 'accounts', 'stream', 'downloads')
+    self.add('AUTH', 'accounts', 'stream', 'token')
     self.add('AUTH', "accounts", "stream/copy")
     self.add('AUTH', "accounts", "stream/direct_upload")
-    self.add('AUTH', "accounts", "stream", "embed")
     self.add('AUTH', "accounts", "stream/keys")
-    self.add('AUTH', "accounts", "stream/preview")
+#   self.add('AUTH', "accounts", "stream/preview")
     self.add('AUTH', "accounts", "stream/watermarks")
     self.add('AUTH', "accounts", "stream/webhook")
+    self.add('AUTH', 'accounts', 'stream/live_inputs')
+    self.add('AUTH', 'accounts', 'stream/live_inputs', 'outputs')
+
 
 def zones_media(self):
     """ API core commands for Cloudflare API"""
@@ -462,7 +509,7 @@ def zones_access(self):
     self.add('AUTH', "zones", "access/apps", "policies")
     self.add('AUTH', "zones", "access/apps", "revoke_tokens")
     self.add('AUTH', "zones", "access/certificates")
-    #self.add('AUTH', "zones", "access/apps/ca")
+#   self.add('AUTH', "zones", "access/apps/ca")
     self.add('AUTH', "zones", "access/apps", "ca")
     self.add('AUTH', "zones", "access/groups")
     self.add('AUTH', "zones", "access/identity_providers")
@@ -474,19 +521,25 @@ def accounts_access(self):
     """ API core commands for Cloudflare API"""
 
     self.add('VOID', "accounts", "access")
-    self.add('AUTH', 'accounts', 'access/certificates')
     self.add('AUTH', "accounts", "access/groups")
     self.add('AUTH', "accounts", "access/identity_providers")
     self.add('AUTH', "accounts", "access/organizations")
     self.add('AUTH', "accounts", "access/organizations/revoke_user")
     self.add('AUTH', "accounts", "access/service_tokens")
-    self.add('VOID', "accounts", "access/logs")
-    self.add('AUTH', 'accounts', 'access/logs/access_requests')
     self.add('AUTH', 'accounts', 'access/apps')
-    #self.add('AUTH', 'accounts', 'access/apps/ca')
+#   self.add('AUTH', 'accounts', 'access/apps/ca')
     self.add('AUTH', 'accounts', 'access/apps', 'ca')
     self.add('AUTH', 'accounts', 'access/apps', 'policies')
     self.add('AUTH', 'accounts', 'access/apps', 'revoke_tokens')
+    self.add('AUTH', 'accounts', 'access/apps', 'user_policy_checks')
+    self.add('AUTH', 'accounts', 'access/certificates')
+    self.add('AUTH', 'accounts', 'access/keys')
+    self.add('AUTH', 'accounts', 'access/keys/rotate')
+    self.add('VOID', 'accounts', 'access/logs')
+    self.add('AUTH', 'accounts', 'access/logs/access_requests')
+    self.add('AUTH', 'accounts', 'access/seats')
+    self.add('AUTH', 'accounts', 'access/users')
+    self.add('AUTH', 'accounts', 'access/users', 'failed_logins')
 
 def accounts_diagnostics(self):
     """ API core commands for Cloudflare API"""
@@ -498,5 +551,127 @@ def zones_waiting_rooms(self):
     """ API core commands for Cloudflare API"""
 
     self.add('AUTH', 'zones', 'waiting_rooms')
+    self.add('AUTH', 'zones', 'waiting_rooms', 'events')
+    self.add('AUTH', 'zones', 'waiting_rooms', 'events', 'details')
     self.add('AUTH', 'zones', 'waiting_rooms', 'status')
     self.add('AUTH', 'zones', 'waiting_rooms/preview')
+
+def accounts_extras(self):
+    """ extras """
+
+    self.add('VOID', 'accounts', 'alerting')
+    self.add('VOID', 'accounts', 'alerting/v3')
+    self.add('AUTH', 'accounts', 'alerting/v3/available_alerts')
+    self.add('VOID', 'accounts', 'alerting/v3/destinations')
+    self.add('AUTH', 'accounts', 'alerting/v3/destinations/eligible')
+    self.add('AUTH', 'accounts', 'alerting/v3/destinations/pagerduty')
+    self.add('AUTH', 'accounts', 'alerting/v3/destinations/webhooks')
+    self.add('AUTH', 'accounts', 'alerting/v3/history')
+    self.add('AUTH', 'accounts', 'alerting/v3/policies')
+
+    self.add('AUTH', 'accounts', 'custom_ns')
+    self.add('AUTH', 'accounts', 'custom_ns/availability')
+    self.add('AUTH', 'accounts', 'custom_ns/verify')
+
+    self.add('AUTH', 'accounts', 'devices')
+    self.add('AUTH', 'accounts', 'devices', 'override_codes')
+    self.add('VOID', 'accounts', 'devices/policy')
+    self.add('AUTH', 'accounts', 'devices/policy/exclude')
+    self.add('AUTH', 'accounts', 'devices/policy/fallback_domains')
+    self.add('AUTH', 'accounts', 'devices/policy/include')
+    self.add('AUTH', 'accounts', 'devices/posture')
+    self.add('AUTH', 'accounts', 'devices/posture/integration')
+    self.add('AUTH', 'accounts', 'devices/revoke')
+    self.add('AUTH', 'accounts', 'devices/settings')
+    self.add('AUTH', 'accounts', 'devices/unrevoke')
+
+    self.add('AUTH', 'accounts', 'dns_firewall')
+    self.add('VOID', 'accounts', 'dns_firewall', 'dns_analytics')
+    self.add('AUTH', 'accounts', 'dns_firewall', 'dns_analytics/report')
+    self.add('AUTH', 'accounts', 'dns_firewall', 'dns_analytics/report/bytime')
+
+    self.add('AUTH', 'accounts', 'gateway')
+    self.add('AUTH', 'accounts', 'gateway/app_types')
+    self.add('AUTH', 'accounts', 'gateway/configuration')
+    self.add('AUTH', 'accounts', 'gateway/lists')
+    self.add('AUTH', 'accounts', 'gateway/lists', 'items')
+    self.add('AUTH', 'accounts', 'gateway/locations')
+    self.add('AUTH', 'accounts', 'gateway/logging')
+    self.add('AUTH', 'accounts', 'gateway/proxy_endpoints')
+    self.add('AUTH', 'accounts', 'gateway/rules')
+
+    self.add('VOID', 'accounts', 'images')
+    self.add('AUTH', 'accounts', 'images/v1')
+    self.add('AUTH', 'accounts', 'images/v1', 'blob')
+    self.add('AUTH', 'accounts', 'images/v1/keys')
+    self.add('AUTH', 'accounts', 'images/v1/stats')
+    self.add('AUTH', 'accounts', 'images/v1/variants')
+    self.add('VOID', 'accounts', 'images/v2')
+    self.add('AUTH', 'accounts', 'images/v2/direct_upload')
+
+    self.add('VOID', 'accounts', 'intel')
+    self.add('VOID', 'accounts', 'intel-phishing')
+    self.add('AUTH', 'accounts', 'intel-phishing/predict')
+    self.add('AUTH', 'accounts', 'intel/dns')
+    self.add('AUTH', 'accounts', 'intel/domain')
+    self.add('AUTH', 'accounts', 'intel/domain-history')
+    self.add('AUTH', 'accounts', 'intel/domain/bulk')
+    self.add('AUTH', 'accounts', 'intel/ip')
+    self.add('AUTH', 'accounts', 'intel/ip-list')
+    self.add('AUTH', 'accounts', 'intel/whois')
+
+    self.add('VOID', 'accounts', 'magic')
+    self.add('AUTH', 'accounts', 'magic/gre_tunnels')
+    self.add('AUTH', 'accounts', 'magic/ipsec_tunnels')
+    self.add('AUTH', 'accounts', 'magic/ipsec_tunnels', 'psk_generate')
+    self.add('AUTH', 'accounts', 'magic/routes')
+
+    self.add('VOID', 'accounts', 'pages')
+    self.add('AUTH', 'accounts', 'pages/projects')
+    self.add('AUTH', 'accounts', 'pages/projects', 'deployments')
+    self.add('VOID', 'accounts', 'pages/projects', 'deployments', 'history')
+    self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'history', 'logs')
+    self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'retry')
+    self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'rollback')
+    self.add('AUTH', 'accounts', 'pages/projects', 'domains')
+
+    self.add('AUTH', 'accounts', 'pcaps')
+    self.add('AUTH', 'accounts', 'pcaps', 'download')
+
+    self.add('VOID', 'accounts', 'teamnet')
+    self.add('AUTH', 'accounts', 'teamnet/routes')
+    self.add('AUTH', 'accounts', 'teamnet/routes/ip')
+    self.add('AUTH', 'accounts', 'teamnet/routes/network')
+    self.add('AUTH', 'accounts', 'teamnet/virtual_network')
+    self.add('AUTH', 'accounts', 'teamnet/virtual_networks')
+
+def zones_extras(self):
+    """ zones extras """
+
+    self.add('VOID', 'zones', 'cache')
+    self.add('AUTH', 'zones', 'cache/variants')
+    self.add('AUTH', 'zones', 'managed_headers')
+    self.add('AUTH', 'zones', 'rulesets')
+    self.add('AUTH', 'zones', 'rulesets', 'versions')
+    self.add('VOID', 'zones', 'rulesets/phases')
+    self.add('AUTH', 'zones', 'rulesets/phases', 'entrypoint')
+    self.add('AUTH', 'zones', 'rulesets/phases', 'entrypoint/versions')
+    self.add('AUTH', 'zones', 'script_monitor')
+    self.add('AUTH', 'zones', 'script_monitor/scripts')
+    self.add('AUTH', 'zones', 'settings/automatic_platform_optimization')
+    self.add('AUTH', 'zones', 'settings/orange_to_orange')
+    self.add('AUTH', 'zones', 'url_normalization')
+
+def accounts_email(self):
+    """ accounts email """
+
+    self.add('AUTH', 'accounts', 'email-fwdr')
+    self.add('AUTH', 'accounts', 'email-fwdr/addresses')
+
+def zones_email(self):
+    """ zones email """
+
+    self.add('AUTH', 'zones', 'email-fwdr')
+    self.add('AUTH', 'zones', 'email-fwdr/dns')
+    self.add('AUTH', 'zones', 'email-fwdr/rules')
+
